/*
 *   Copyright 2011 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package net.brutex.xservices.types;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 * Different pre-defined date formats.
 *
 * @author Brian Rosenberger, bru@brutex.de
 */
@XmlEnum(value = String.class)
public enum DateFormatType {

    /**
     * ISO 8601 format (2011-05-24T14:39Z)
     */
    @XmlEnumValue("ISO 8601")
    ISO8601("ISO 8601", "yyyy-MM-dd'T'HH:mm:ssZ"),
    /**
     * yyyy/mm/dd
     */
    @XmlEnumValue("yyyy/mm/dd")
    YYYYMMDD("yyyy/mm/dd", "yyyy/MM/dd"),
    
    /**
     * dd.mm.yyyy
     */
    @XmlEnumValue("dd.mm.yyyy")
    DDMMYY("dd.mm.yyyy", "dd.MM.yyyy");
    
    private String value;
    private String format;
    
    DateFormatType(String value, String format) {
        this.value = value;
        this.format = format;
    }

    /**
     * Return the value of the enum.
     * @return  String representation of the mime type
     */
    public String value() {
        return value;
    }
    
    public String format() {
    	return format;
    }
}
